
grgrjax
=======

This library provides some useful additional tools to `JAX <https://github.com/google/jax>`_, such as a `multivariate Newton method <https://en.wikipedia.org/wiki/Newton%27s_method#k_variables,_k_functions>`_, ``val_and_jacfwd`` or vectorized JVP and VJP functions.

The module `documentation <https://grgrjax.readthedocs.io/en/stable/>`_ can be found on Readthedocs.

Installation with ``pip``
-----------------------------

It's as simple as typing

.. code-block:: bash

   pip install grgrjax

in the terminal (Unix/Mac) or the Anaconda Prompt (Win).
